floating_palette_annotations library

Annotations for floating_palette code generation.

This package contains only pure Dart annotations with no Flutter dependencies, allowing it to be used by build_runner generators.

Classes

Event
Registers an event type for a palette.
FloatingPaletteApp
Annotation to define a floating palette application.
PaletteAnnotation
Definition of a single palette for code generation.
PaletteCommand
Marks a method as a command in a service schema.
PaletteDefaults
Default configuration applied to all palettes.
PaletteEventType
Marks a class as a palette event type for code generation.
PaletteNativeEvent
Marks a method as a native event handler in a service schema.
PaletteParams
Marks a class as command/event parameters for code generation.
PaletteService
Marks a class as a service schema for code generation.

Enums

OnHideFocus
What happens to focus when a palette is hidden.
Preset
Pre-configured palette types for common use cases.
TakesFocus
Whether the palette takes keyboard focus when shown.