Event class

Registers an event type for a palette.

Event IDs are auto-generated as ${eventNamespace}.${snake_case(className)}. The namespace defaults to the palette ID, or can be overridden with PaletteAnnotation.eventNamespace. The 'Event' suffix is stripped if present.

PaletteAnnotation(
  id: 'editor',
  widget: EditorPalette,
  events: [
    Event(FilterChanged),   // → editor.filter_changed
    Event(SlashTrigger),    // → editor.slash_trigger
  ],
)

Constructors

Event(Type type)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
The event class type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited